/*---------------------------------------------------------------------------

    Written by the Personal Journal developers of Dow Jones & Company, Inc.

    Dow Jones makes no representations or warranties about 
    the suitability of this software, either express or 
    implied, including but not limited to the implied warranties 
    of merchantability, fitness for a particular purpose, 
    or non-infringement.  Dow Jones will not be liable for 
    any damages suffered by a user as a result of using, 
    modifying or distributing this software or its derivatives.


    @(#)DownloadThread.java   0.00 09-Jan-95

        A thread which connects to a URL (or uses Stdin for debugging)
        and runs an instance of pj.io.StoryParser.

    Authors:

        rphall      Rick Hall
        jlee        james lee

    Version Ident:

        $Header: /PjJavaClient/src/pj/applet/DownloadThread.java 2     1/21/96 6:26p Rphall $

    History:

        09-Jan-95    rphall      Initial Creation
        20-Mar-96    jlee        Added thread's priority change scheme
        26-Mar-96    jlee        DownloadThread's prioriy changes upon PjFrame's visibleness.

---------------------------------------------------------------------------*/

package pj.applet;

import pj.applet.PjJava;
import pj.io.Paper;
import pj.io.PaperSection;
import pj.io.StoryContainerNotification;
import pj.io.StoryParser;

import java.awt.Frame;
import java.io.InputStream;
import java.io.IOException;
import java.lang.Thread;
import java.lang.ThreadGroup;
import java.net.URL;
import java.net.URLConnection;
import java.util.Observable;
import java.util.Observer;


/**
*
*  Connects to a URL and runs an instance of pj.io.StoryParser.
*
*  @see        pj.io.StoryParser
*  @version    0.00     09-Jan-95
*  @author     rphall
*/
public class DownloadThread extends Thread implements Observer
    {

    // --- Instance variables
    private boolean bStayAlive;
    private URL url;
    private Paper paper;

    // --- Public Constructor

    public DownloadThread(URL u, Paper p)
        {
        bStayAlive = true;
        url = u;
        paper = p;

        System.out.println("Debug-DownloadThread:constructed");
        }

    // --- Public Operations

    public void run()
        {
        // Observe paper
        paper.addObserver(this);

        InputStream is = null;
        URLConnection urlcConnection;
        if (url != null)
            {
            try {
                urlcConnection = url.openConnection();
                is = url.openStream();
                }
            catch(IOException e)
                {
                System.out.println("Debug DownloadThread run, exception " + e.toString() );
                return;
                }
            }
        else
            is = System.in;

        // Create parser and start parsing
        StoryParser parse_obj = new StoryParser(is,paper);
        try {
            parse_obj.parse();
            }
        catch(Exception e)
            {
            System.out.println("Debug DownloadThread run, exception " + e.toString() );
            return;
            }

        // Hang out until notified of EOT
        while (bStayAlive);

        } // run

    public synchronized void update(Observable who, Object arg)
        {
        if ( !(arg instanceof StoryContainerNotification) )
            return;

        if ( PjJava.getPjFrame().isVisible() )
            this.setPriority( Thread.MAX_PRIORITY );

        StoryContainerNotification scn = (StoryContainerNotification) arg;
        if (scn.newState != PaperSection.stateAdded)
            return;

        // Kludge: should define PaperNotificationEOT
        if (scn.strSubsect.equals(Paper.idPcolEOT))
            {
            //isContent.flush();
            bStayAlive = false;
            }
        } // update

    public void finalize()
        {
        if ( isAlive() )
            stop();
        System.out.println("Debug-DownloadThread-finalize:passed");
        }
    } // DownloadThread
