/*---------------------------------------------------------------------------

    Written by the Personal Journal developers of Dow Jones & Company, Inc.

    Dow Jones makes no representations or warranties about 
    the suitability of this software, either express or 
    implied, including but not limited to the implied warranties 
    of merchantability, fitness for a particular purpose, 
    or non-infringement.  Dow Jones will not be liable for 
    any damages suffered by a user as a result of using, 
    modifying or distributing this software or its derivatives.


    @(#)Page.java  0.00 01-Jan-96

        A Nameable Panel.

    Authors:

        rphall   Rick Hall

    Version Ident:

        $Header$

    History:

        0.00 01-Jan-96  rphall      Initial Creation
        0.01  1-Mar-96  Ted S.      implements PaperView.  This is quite handy
                                        because it elminates all the derived 
                                        classes that solely implement PaperView.
                                        Also, it isolates the code that keeps
                                        track of where you are and when you have
                                        run out of nextViews.  So from now on,
                                        you can say nextView() to anything derived from
                                        paper.  The default behavior is a false return value.
	    0.02  19-Mar-96  Ted S.     Filled in code for View( idx );
        0.03  26-Mar-96  Ted S.     Allowed derived class to tell us what the current view is.
                                        see Section class.
---------------------------------------------------------------------------*/

package pj.awt;

import pj.util.Nameable;

import java.awt.Panel;
import java.awt.BorderLayout;

/**
 * A Nameable Panel.
 *
 * @see     pj.util.Nameable
 * @see     java.awt.Panel
 * @see     pj.awt.Notebook
 * @version 0.00 01-Jan-96
 * @author  rphall
*/
public class Page extends Panel implements Nameable, PaperView
    {

    
    // --- Instance variables

    //   Keep track of the current view.  This is 1 based.
    //   Without this I don't know when I've hit the last view.

    int nCurrView; 

    String strPageName;


    // --- Public constructors

    /**
     * Construct a Page with a given name.
     * @param name  The name for a page
    */
    public Page(String name)
        {
        // Set the current view for the page.
        nCurrView = 1;
        setLayout( new BorderLayout(4, 4) );
        strPageName = name;
        }

    /**
     * Construct a Page with a null name.
    */
    public Page()
        { 
        this(null); 
        // Set the current view for the page.
        nCurrView = 1;
        }

    // --- Public operations

    /**
     * @param name  The name for a page.
    */
    public void setName(String name)
        {   
        strPageName = name; 
        }

    /**
     * @return  The name of a page.
    */
    public String getName()
        { 
        return strPageName; 
        }


         
        
    /**
     * @return The number of views in an implementation instance.
    */
    public int countViews()
        {
        return 1;
        }
 
    

    /**
     * Make the first view the current view.
    */
    public void firstView()
        {
        nCurrView = 1;
        }

    /**
     * Make the next view (after the current view) the current view.
     *  a false return means you have hit the end.
    */
    public boolean nextView()
        {
        boolean bRet;                	
				     
        // Make sure we can do another next, 
        //  if not return false.
        if ( countViews() == currView() )
            {
            bRet = false;
            }
        else
            {
            nCurrView = currView() + 1;
            bRet = true;
            }    
                
        return bRet;
        }

    /**
     * Make the last view the current view.
    */
    public void lastView()
        {
        nCurrView = countViews();
        }

    /**
     * Make the previous view (before current view) the current view.
     *  a false return means you have hit the end.
    */
    public boolean previousView()
        {
        boolean bRet;
        // Make sure we can do another prev, if not return false.

        if ( 1 == currView() )
            {
            bRet = false;
            }
        else
            {
            nCurrView = currView() - 1;
            bRet = true;
            }   

        return bRet;     
        }

    
     
    /**
     * Make a specific view the current view.
     * @param idx The index of the view to display.
    */
    public void view(int idx)
        {
        if (( idx > 0 ) && ( idx <= countViews() ) )
			{
			nCurrView = idx;
			}
        }

    /**
     * Get the index of the current view.
     * @return The index of the view being displayed.
    */
    public int currView()
        {
		return nCurrView;
        } 
	

   


    } // Page
