/*---------------------------------------------------------------------------

    Written by the Personal Journal developers of Dow Jones & Company, Inc.

    Dow Jones makes no representations or warranties about 
    the suitability of this software, either express or 
    implied, including but not limited to the implied warranties 
    of merchantability, fitness for a particular purpose, 
    or non-infringement.  Dow Jones will not be liable for 
    any damages suffered by a user as a result of using, 
    modifying or distributing this software or its derivatives.


    PjSizes.java

        A specification of the sizes of various components in Personal Journal.


    Authors:

        jlee          James Lee


    Version Ident:

    $Header: /PjJavaClient/src/pj/awt/PjSizes.java 10    3/22/96 11:13p Jlee $


    History:

        15-Feb-1996     jlee    Initial Creation
        21-Feb-1996     jlee    Changed default modifier for PjSizes class to "public final" and
                                changed the value of nPjAdTextBoxWidth from 280 to 290.
         1-Mar-1996     jlee    Added default PjJava Applet width & height and changed
                                nPjAdTextBoxHeight from 75 to 81.
         4-Mar-1996     jlee    Added fixed height of 3D tab used in PjTabNotebook:nTab3DHeight.
         5-Mar-1996     jlee    Added Fixed height of status bar.
        12-Mar-1996     jlee    Added fonts constants.
        25-Mar-1996     jlee    Added fntInfoBar
        27-Mar-1996     jlee    Changed PjFrame's height from 510 to 545
        28-Mar-1996     jlee    Added AboutDialog box text fonts and added dimTickerSize for Ticker
                                Added nTextBoxHorInset.
---------------------------------------------------------------------------*/

package pj.awt;

import java.awt.Button;
import java.awt.Dimension;
import java.awt.Font;

/**
 * PjSizes defines various fixed sizes used for component layouts.
 * @version     0.00, 2/15/96
 * @author      James Lee
 */
public final class PjSizes
    {
    // --- Class variables

    //Fixed width for Advertisement image
    public static final int nPjAdImageWidth     = 137;

    //Fixed height for Advertisement image
    public static final int nPjAdImageHeight    = 75;

    //Fixed width for Advertisement text box width
    public static final int nPjAdTextBoxWidth   = 290;

    //Fixed height for Advertisement text box height.
    public static final int nPjAdTextBoxHeight  = 76;

    //Default height for buttons
    public static final int nPjButtonHeight     = 21;

    //Default height for labels
    public static final int nPjLabelHeight      = 21;

    //Default vertical spacing between components.
    public static final int nPjVerticalSpacing  = 2;

    //Default horizontal spacing between components.
    public static final int nPjHorizontalSpacing    = 2;

    //Default width of PjJava Applet.
    public static final int nPjDefaultAppletWidth   = 640;

    //Default height of PjJava Applet.
    public static final int nPjDefaultAppletHeight  = 545;

    //Fixed height of 3D tab used in PjTabNotebook.
    public static final int nTab3DHeight        = 27;

    //Fixed height of ticker panel.
    public static final int nTickerPanelHeight  = 28;

    //Fixed height of status bar.
    public static final int nStatusBarHeight    = 23;

    //Fixed width of scroll bar.
    public static final int nScrollbarWidth     = 21;

    //Fixed width for Button in TitleList.
    public static final int nTitleListButtonWidth   = 29;

    //Fixed height for Button in TitleList.
    public static final int nTitleListButtonHeight  = 26;

    //Fixed inset used in TextBox drawing
    public static final int nTextBoxHorInset  = 4;

    //Fixed size for About Diaog box OK button.
    public static final Dimension dimOKButton  =  new Dimension( 90, 30 );

    //Fixed size for About Diaog box image.
    public static final Dimension dimAboutBoxImage  =  new Dimension( 175, 35 );

    //Fixed size for About Diaog box.
    public static final Dimension dimAboutDialogSize  =  new Dimension( 450, 320 );

    //Fixed size for Ticker.
    public static final Dimension dimTickerSize  = new Dimension(640, 27);

    //The minimum width of PageView
    public static final int nPjMinimumPageViewWidth = nPjAdImageWidth + nPjAdTextBoxWidth + nPjHorizontalSpacing;

    //Font used for formatted column.
    public static final Font fntFormattedColumn = new Font( "Courier", Font.PLAIN, 12 );

    //Font used for unformatted column plain.
    public static final Font fntUnfColumnPlain  = new Font( "Helvetica", Font.PLAIN, 13 );

    //Font used for unformatted column bold.
    public static final Font fntUnfColumnBold   = new Font( "Helvetica", Font.BOLD, 14 );

    //Font used for ad text plain.
    public static final Font fntAdTextPlain     = new Font( "Helvetica", Font.PLAIN, 12 );

    //Font used for Section or Page title.
    public static final Font fntSectionBigTitle = new Font( "Helvetica", Font.BOLD, 25 );

    //Font used for DJChart title font.
    public static final Font fntDJChartTitle    = new Font("Courier", Font.BOLD, 12);

    //Font used for Column label.
    public static final Font fntColumnLabel     = new Font( "Helvetica", Font.BOLD, 12 );

    //Font used for Status bar.
    public static final Font fntStatusBar       = new Font( "Helvetica", Font.BOLD, 15 );

    //Font used for Info bar.
    public static final Font fntInfoBar         = new Font( "Helvetica", Font.PLAIN, 12 );

    //Font used for Personal news title list button.
    public static final Font fntPNButton        = new Font( "Helvetica", Font.BOLD, 12 );

    //Font used for Personal news text field.
    public static final Font fntPNTextField     = new Font( "Helvetica", Font.PLAIN, 13 );

    //Font used for AboutBox text.
    public static final Font fntAboutBoxTextPlain    = new Font( "Helvetica", Font.PLAIN, 13 );

    //Font used for AboutBox text.
    public static final Font fntAboutBoxTextBold    = new Font( "Helvetica", Font.BOLD, 13 );

    //Font used for AboutBox text.
    public static final Font fntAboutBoxTextItalic    = new Font( "Helvetica", Font.ITALIC, 13 );
    }
